lscorehom: Likelihood Score test for homogeneity of kappa statistics
Description
Likelihood Score test for homogeneity of kappa statistics
Usage
lscorehom(pp, pm, mm)
Arguments
pp
a number vector carrying the number of positive maching rates for each study
pm
a number vector carrying the number of non-maching rates for each study
mm
a number vector carrying the number of negative maching for each study
Value
This function prints the Likelihood Score test statistic, P-value for hypothesis test of the statistic and whether the difference is statistically significant or not.
Details
This function can be used only for studies with binary output